OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "No file provided for import" : "No se especificó un archivo para importar",
    "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Delete" : "Borrar",
    "Select all" : "Seleccionar todo",
    "New" : "Nuevo",
    "New folder" : "Carpeta nueva",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Recent" : "Reciente",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Bookmarklet" : "Marcador a código ",
    "Clear data" : "Borrar datos",
    "Title" : "Título",
    "Link" : "Liga",
    "Tags" : "Etiquetas",
    "Notes" : "Notas",
    "Owner" : "Dueño",
    "Sharing" : "Compartiendo",
    "Share link" : "Compartir liga",
    "Copy link" : "Copiar liga",
    "Allow editing" : "Permitir edición",
    "Link copied" : "Enlace copiado",
    "Privacy" : "Privacidad",
    "Add a bookmark" : "Agregar un marcador",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
    "Folder" : "Carpeta",
    "Save" : "Guardar"
},
"nplurals=2; plural=(n != 1);");
